"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const helper_plugin_utils_1 = require("@babel/helper-plugin-utils");
// @ts-ignore
const plugin_syntax_typescript_1 = __importDefault(require("@babel/plugin-syntax-typescript"));
exports.default = (0, helper_plugin_utils_1.declare)((api, options) => {
    api.assertVersion(7);
    const { types: t } = api;
    const { reflect = true } = options;
    return {
        name: 'enum-to-object',
        // eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
        inherits: plugin_syntax_typescript_1.default,
        visitor: {
            TSEnumDeclaration(path) {
                const { node } = path;
                const { id, members } = node;
                const objProperties = [];
                let preNum = -1;
                members.forEach((member) => {
                    let { initializer, id: memberId } = member;
                    if (!initializer) {
                        preNum++;
                        initializer = t.numericLiteral(preNum);
                    }
                    else if (t.isNumericLiteral(initializer)) {
                        preNum = initializer.value;
                    }
                    const objProerty = t.objectProperty(memberId, initializer);
                    objProperties.push(objProerty);
                    if (reflect) {
                        // add reflect
                        const key = t.identifier(String(objProerty.value.value));
                        const value = t.stringLiteral(t.isIdentifier(memberId) ? memberId.name : memberId.value);
                        if (key.name === value.value)
                            return;
                        objProperties.push(t.objectProperty(t.identifier(String(objProerty.value.value)), t.stringLiteral(t.isIdentifier(memberId) ? memberId.name : memberId.value)));
                    }
                });
                const obj = t.variableDeclarator(id, t.objectExpression(objProperties));
                const constObjVariable = t.variableDeclaration('const', [obj]);
                path.replaceWith(constObjVariable);
            },
        },
    };
});
